euMetabCData:
A sample data set of truncated metabolomics data.
Description
This data set contains a subset of non-targeted GC/MS data for mother / baby pairs of Northern European ancestry who participated in the Hyperglycemia and Adverse Pregnancy Outcome (HAPO) Metabolomics study.
Usage
data("euMetabCData")
Format
A data frame with 30 observations on the following 6 variables.
batch- A factor variable for the batch in which the sample was processed with levels
1 2 3 4 5. pheno- A factor variable indicating whether the serum sample was from a mother or baby with levels
BABY MOM. betahydroxybutyrate- A numeric vector of non-normalized GC/MS log2 transformed peak areas for this metabolite.
pyruvic_acid- A numeric vector of non-normalized GC/MS log2 transformed peak areas for this metabolite.
malonic_acid- A numeric vector of non-normalized GC/MS log2 transformed peak areas for this metabolite.
aspartic_acid- A numeric vector of non-normalized GC/MS log2 transformed peak areas for this metabolite.
Details
The 30 rows correspond to 3 mom and 3 baby control samples run at the beginning, middle and end of each batch. All control samples were drawn from an identical pool.