yvals-methods: ~~ Methods for Function yvals ~~
Description
~~ Methods for function yvals ~~
Methods
signature(y="data.frame",n="character")-
The columns of data frame 'y' with names 'n' are converted to a data frame, whose columns are to be used as the response variables in the specified mixture model.
signature(y="ExpressionSet",n="character")-
The rows of the assayData section of expression set 'y' with names 'n' are converted to a data frame, whose columns are to be used as the response variables in the specified mixture model.
signature(y="matrix",n="character")-
The columns of matrix 'y' with names 'n' are converted to a data frame, whose columns are to be used as the response variables in the specified mixture model.